# NLFFF 3D Dataset

> [A Large-Scale Nonlinear Force-Free Field Three-Dimensional Magnetic Fields Data of Solar Active Regions](https://nlfff.dataset.deepsolar.space)

Based on the vector magnetic field data observed by Helioseismic and Magnetic Imager([HMI](http://hmi.stanford.edu)) on the Solar Dynamics Observatory (SDO), we have built a 3D solar  active region magnetic field dataset using the Nonlinear Force-Free  Coronal Magnetic Field ([NLFFF](https://doi.org/10.1007/s11207-012-9966-z))Extrapolations.

The current total is over 200 TB, 73,000 3D magnetograms  spanning the years 2010 to 2019, with a temporal resolution of 96  minutes and a spatial resolution consistent with the original [sharp cea magnetograms](http://jsoc.stanford.edu/doc/data/hmi/sharp/sharp.htm).



# Toolkit

Install

```bash
pip install pynlfff
# or
pip install git+https://github.com/deepsolar/pynlfff.git
```

Usage

<https://nlfff.dataset.deepsolar.space>

